@@ -23,7 +23,7 @@ describe 'openstacklib::wsgi::apache' do
 
   let :global_facts do
     {
-      :processorcount => 42,
+      :os_workers     => 8,
       :concat_basedir => '/var/lib/puppet/concat',
       :fqdn           => 'some.host.tld'
     }
@@ -37,12 +37,14 @@ describe 'openstacklib::wsgi::apache' do
       :user               => 'keystone',
       :wsgi_script_dir    => '/var/www/cgi-bin/keystone',
       :wsgi_script_file   => 'main',
-      :wsgi_script_source => '/usr/share/keystone/keystone.wsgi'
+      :wsgi_script_source => '/usr/share/keystone/keystone.wsgi',
+      :access_log_file    => false,
+      :access_log_format  => false,
     }
   end
 
   shared_examples_for 'apache serving a service with mod_wsgi' do
-    it { is_expected.to contain_service('httpd').with_name(platform_parameters[:httpd_service_name]) }
+    it { is_expected.to contain_service('httpd').with_name(platform_params[:httpd_service_name]) }
     it { is_expected.to contain_class('apache') }
     it { is_expected.to contain_class('apache::mod::wsgi') }
 
@@ -52,11 +54,11 @@ describe 'openstacklib::wsgi::apache' do
         'ensure'  => 'directory',
         'owner'   => 'keystone',
         'group'   => 'keystone',
-        'require' => 'Package[httpd]'
       )}
 
       it { is_expected.to contain_file('keystone_wsgi').with(
         'ensure'  => 'file',
+	'links'   => 'follow',
         'path'    => '/var/www/cgi-bin/keystone/main',
         'source'  => '/usr/share/keystone/keystone.wsgi',
         'owner'   => 'keystone',
@@ -76,16 +78,18 @@ describe 'openstacklib::wsgi::apache' do
         'wsgi_process_group'          => 'keystone_wsgi',
         'wsgi_script_aliases'         => { '/' => "/var/www/cgi-bin/keystone/main" },
         'wsgi_daemon_process_options' => {
-          'user'      => 'keystone',
-          'group'     => 'keystone',
-          'processes' => 1,
-          'threads'   => global_facts[:processorcount],
+          'user'         => 'keystone',
+          'group'        => 'keystone',
+          'processes'    => global_facts[:os_workers],
+          'threads'      => 1,
+          'display-name' => 'keystone_wsgi',
         },
         'wsgi_application_group'      => '%{GLOBAL}',
-        'require'                     => 'File[keystone_wsgi]',
-        'setenvif'                    => ['X-Forwarded-Proto https HTTPS=1']
+        'setenvif'                    => ['X-Forwarded-Proto https HTTPS=1'],
+        'access_log_file'             => false,
+        'access_log_format'           => false,
       )}
-      it { is_expected.to contain_concat("#{platform_parameters[:httpd_ports_file]}") }
+      it { is_expected.to contain_concat("#{platform_params[:httpd_ports_file]}") }
     end
 
     describe 'when overriding parameters' do
@@ -95,6 +99,7 @@ describe 'openstacklib::wsgi::apache' do
           :wsgi_script_file        => 'main',
           :wsgi_script_source      => '/usr/share/keystone/keystone.wsgi',
           :wsgi_pass_authorization => 'On',
+          :wsgi_chunked_request    => 'On',
           :servername              => 'dummy.host',
           :bind_host               => '10.42.51.1',
           :bind_port               => 4142,
@@ -102,7 +107,11 @@ describe 'openstacklib::wsgi::apache' do
           :group                   => 'keystone',
           :ssl                     => false,
           :workers                 => 37,
-          :vhost_custom_fragment   => 'LimitRequestFieldSize 81900'
+          :vhost_custom_fragment   => 'LimitRequestFieldSize 81900',
+          :allow_encoded_slashes   => 'on',
+          :access_log_file         => '/var/log/httpd/access_log',
+          :access_log_format       => 'some format',
+          :error_log_file          => '/var/log/httpd/error_log'
         }
       end
       it { is_expected.to contain_apache__vhost('keystone_wsgi').with(
@@ -113,57 +122,76 @@ describe 'openstacklib::wsgi::apache' do
         'ssl'                         => 'false',
         'wsgi_daemon_process'         => 'keystone_wsgi',
         'wsgi_daemon_process_options' => {
-            'user'      => 'keystone',
-            'group'     => 'keystone',
-            'processes' => '37',
-            'threads'   => '42',
+            'user'         => 'keystone',
+            'group'        => 'keystone',
+            'processes'    => '37',
+            'threads'      => '1',
+            'display-name' => 'keystone_wsgi',
         },
         'wsgi_process_group'          => 'keystone_wsgi',
         'wsgi_script_aliases'         => { '/' => "/var/www/cgi-bin/keystone/main" },
         'wsgi_application_group'      => '%{GLOBAL}',
         'wsgi_pass_authorization'     => 'On',
-        'require'                     => 'File[keystone_wsgi]',
+        'wsgi_chunked_request'        => 'On',
         'custom_fragment'             => 'LimitRequestFieldSize 81900',
+        'allow_encoded_slashes'       => 'on',
+        'access_log_file'             => '/var/log/httpd/access_log',
+        'access_log_format'           => 'some format',
+        'error_log_file'              => '/var/log/httpd/error_log'
       )}
 
     end
 
+    describe 'when wsgi_daemon_process_options are overriden' do
+      let :params do
+        {
+          :bind_port                   => 5000,
+          :group                       => 'keystone',
+          :ssl                         => true,
+          :user                        => 'keystone',
+          :wsgi_script_dir             => '/var/www/cgi-bin/keystone',
+          :wsgi_script_file            => 'main',
+          :wsgi_script_source          => '/usr/share/keystone/keystone.wsgi',
+          :custom_wsgi_process_options => {
+            'user'        => 'someotheruser',
+            'group'       => 'someothergroup',
+            'python_path' => '/my/python/admin/path',
+          },
+        }
+      end
+      it { is_expected.to contain_apache__vhost('keystone_wsgi').with(
+        'wsgi_daemon_process_options' => {
+          'user'         => 'someotheruser',
+          'group'        => 'someothergroup',
+          'processes'    => global_facts[:os_workers],
+          'threads'      => 1,
+          'display-name' => 'keystone_wsgi',
+          'python_path'  => '/my/python/admin/path',
+        },
+      )}
+    end
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      global_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystemrelease => '7.0'
-      })
-    end
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts(global_facts))
+      end
 
-    let :platform_parameters do
-      {
-        :httpd_service_name => 'httpd',
-        :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
-      }
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :httpd_service_name => 'apache2',
+            :httpd_ports_file   => '/etc/apache2/ports.conf', }
+        when 'RedHat'
+          { :httpd_service_name => 'httpd',
+            :httpd_ports_file   => '/etc/httpd/conf/ports.conf', }
+        end
+      end
+      it_configures 'apache serving a service with mod_wsgi'
     end
-
-    it_configures 'apache serving a service with mod_wsgi'
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      global_facts.merge({
-        :osfamily               => 'Debian',
-        :operatingsystem        => 'Debian',
-        :operatingsystemrelease => '7.0'
-      })
-    end
-
-    let :platform_parameters do
-      {
-        :httpd_service_name => 'apache2',
-        :httpd_ports_file   => '/etc/apache2/ports.conf',
-      }
-    end
-
-    it_configures 'apache serving a service with mod_wsgi'
-  end
 end
